CREATE TABLE norm_class_teachers (teacher_id bigint PRIMARY KEY AUTO_INCREMENT,
groupid bigint REFERENCES groups (groupid) ON DELETE CASCADE,
uid bigint REFERENCES users (uid) ON DELETE CASCADE,
linkid bigint REFERENCES groups_users_link (linkid) ON DELETE CASCADE
) DEFAULT CHARACTER SET utf8;

CREATE TABLE norm_department_tbl (department_id int PRIMARY KEY AUTO_INCREMENT,
department_nam TEXT NOT NULL, comment TEXT) DEFAULT CHARACTER SET utf8;

CREATE TABLE norm_txt_level_tbl (txt_level_id int PRIMARY KEY AUTO_INCREMENT,
txt_level_nam TEXT NOT NULL, comment TEXT) DEFAULT CHARACTER SET utf8;

CREATE TABLE norm_difficulty_tbl (difficulty_id int PRIMARY KEY AUTO_INCREMENT,
difficulty_nam TEXT NOT NULL, comment TEXT) DEFAULT CHARACTER SET utf8;

CREATE TABLE norm_class_student_tbl (
class_student_id int PRIMARY KEY AUTO_INCREMENT,
uid bigint REFERENCES users (uid) ON DELETE CASCADE,
groupid bigint REFERENCES groups (groupid) ON DELETE CASCADE,
student_comment text,
teacher_comment text,
present int DEFAULT 0,status int DEFAULT 0,
st_status int,
linkid bigint REFERENCES groups_users_link (linkid) ON DELETE CASCADE,
CONSTRAINT class_student_tbl_uni UNIQUE(uid, groupid)
) DEFAULT CHARACTER SET utf8;

CREATE TABLE norm_mobile_tbl (
mobile_user_id bigint PRIMARY KEY AUTO_INCREMENT,
usr_id bigint REFERENCES users (uid) ON DELETE CASCADE,
mobile_id character varying(200) UNIQUE,
create_time datetime, update_time datetime
) DEFAULT CHARACTER SET utf8;

CREATE TABLE norm_question_tbl (practice_id bigint PRIMARY KEY AUTO_INCREMENT,
practice_title text,
practice_text text,
cre_teacher_id bigint REFERENCES users (uid) ON DELETE SET NULL,
cre_student_id bigint REFERENCES users (uid) ON DELETE SET NULL,
img_file text, av_file text, level int,
department int REFERENCES department_tbl (department_id) ON DELETE SET NULL,
real_dif int,
exp_dif int,
answer int,
status int,
create_time datetime,
update_time datetime,
comment text,
parent_practice bigint,
parent_question bigint,
is_new int NOT NULL DEFAULT 1,
exp_dur int) DEFAULT CHARACTER SET utf8;

CREATE TABLE norm_item_tbl (
practice_id bigint NOT NULL REFERENCES norm_question_tbl(practice_id) ON DELETE CASCADE,
item_order character varying(2) NOT NULL,
item_txt text NOT NULL,
is_right int NOT NULL,
comment text,
CONSTRAINT norm_item_tbl_pk PRIMARY KEY(practice_id, item_order)
) DEFAULT CHARACTER SET utf8;

CREATE TABLE norm_vote_tbl (
vote_id bigint PRIMARY KEY AUTO_INCREMENT,
vote_title text,
vote_text text,
vote_comment text,
department_id int,
answer int,
img_url text,
create_user bigint REFERENCES users (uid) ON DELETE CASCADE,
create_time datetime,
update_time datetime
)DEFAULT CHARACTER SET utf8;

CREATE TABLE norm_vote_item_tbl (
vote_id bigint NOT NULL REFERENCES norm_vote_tbl(vote_id) ON DELETE CASCADE,
item_order character varying(4) NOT NULL,
item_txt text NOT NULL,
CONSTRAINT vote_item_tbl_pk PRIMARY KEY(vote_id, item_order))
DEFAULT CHARACTER SET utf8;

CREATE TABLE norm_lecture_tbl (
lecture_id bigint PRIMARY KEY AUTO_INCREMENT,
lecture_nam character varying(50) NOT NULL,
teacher_id bigint REFERENCES class_teachers(teacher_id) ON DELETE SET NULL,
groupid bigint REFERENCES groups (groupid) ON DELETE CASCADE,
make_date timestamp NOT NULL DEFAULT now(),
lecture_date timestamp,
duration int DEFAULT 0,
status int NOT NULL DEFAULT 0,
current_event bigint REFERENCES norm_event_link_tbl(event_link_id) ON DELETE SET NULL,
partici_num int DEFAULT 0,sd_score float8 DEFAULT 0,
lecture_type smallint DEFAULT 0,
invite_key character varying(4),
comment text,
pres_key character varying(4),
pres_type smallint NOT NULL DEFAULT 0,
pres_note_percent smallint NOT NULL DEFAULT 0,
pres_right_percent smallint NOT NULL DEFAULT 0,
pres_submit_percent smallint NOT NULL DEFAULT 0,
pres_quiz_percent smallint NOT NULL DEFAULT 0
) DEFAULT CHARACTER SET utf8;

CREATE TABLE norm_event_link_tbl (
event_link_id bigint PRIMARY KEY AUTO_INCREMENT,
lecture_id bigint REFERENCES norm_lecture_tbl (lecture_id) ON DELETE SET NULL,
event_id bigint,
event_type int,
display_type int,
status int,
create_time datetime
)DEFAULT CHARACTER SET utf8;

CREATE TABLE norm_key_word_tbl (
key_word_id bigint PRIMARY KEY AUTO_INCREMENT,
practice_id bigint,
key_word_txt character varying(200) binary NOT NULL,
score_weight int NOT NULL DEFAULT 0,
comment text,
CONSTRAINT norm_key_word_tbl_pk UNIQUE(practice_id, key_word_txt)
) DEFAULT CHARACTER SET utf8;

CREATE TABLE norm_question_result_tbl (practice_result_id bigint PRIMARY KEY AUTO_INCREMENT,
usr_id bigint REFERENCES users (uid) ON DELETE CASCADE,
department_id int REFERENCES department_tbl (department_id) ON DELETE SET NULL,
practice_id bigint,
practice_time timestamp DEFAULT now(),
answered text,
is_right smallint,
duration int)
DEFAULT CHARACTER SET utf8;

CREATE TABLE norm_vote_answer_tbl (
vote_answer_id bigint PRIMARY KEY AUTO_INCREMENT,
event_link_id bigint NOT NULL REFERENCES norm_event_link_tbl(event_link_id) ON DELETE CASCADE,
uid bigint REFERENCES users (uid) ON DELETE SET NULL,
access_time datetime,
answer text,
CONSTRAINT norm_vote_answer_tbl_pk UNIQUE(event_link_id, uid)
)DEFAULT CHARACTER SET utf8;

CREATE TABLE norm_lec_prac_answer_tbl (
lec_prac_answer_id bigint PRIMARY KEY AUTO_INCREMENT,
event_link_id bigint NOT NULL REFERENCES norm_event_link_tbl(event_link_id) ON DELETE CASCADE,
uid bigint REFERENCES users (uid) ON DELETE SET NULL,
access_time datetime,
answer text,
is_right int,
CONSTRAINT norm_lec_prac_answer_tbl_pk UNIQUE(event_link_id, uid)
)DEFAULT CHARACTER SET utf8;

CREATE TABLE norm_material_tbl (
material_id bigint PRIMARY KEY AUTO_INCREMENT,
material_title text,
material_url text,
material_comment text,
department_id int REFERENCES department_tbl (department_id) ON DELETE SET NULL,
create_time datetime,
update_time datetime,
create_user bigint REFERENCES users (uid) ON DELETE SET NULL,
update_user bigint REFERENCES users (uid) ON DELETE SET NULL,
is_pub int,
groupid bigint REFERENCES groups (groupid) ON DELETE SET NULL
)DEFAULT CHARACTER SET utf8;

CREATE TABLE norm_note_tbl (
note_id bigint PRIMARY KEY AUTO_INCREMENT,
student_id bigint REFERENCES users (uid) ON DELETE CASCADE,
event_link_id bigint NOT NULL REFERENCES norm_event_link_tbl(event_link_id) ON DELETE CASCADE,
note_text text,
create_time datetime,
update_time datetime,
pub_status smallint NOT NULL DEFAULT '0'
) DEFAULT CHARACTER SET utf8;

CREATE TABLE norm_feedback_comment_tbl (
feedback_comment_id bigint PRIMARY KEY AUTO_INCREMENT,
uid bigint REFERENCES users (uid) ON DELETE SET NULL,
lecture_id bigint REFERENCES norm_lecture_tbl (lecture_id) ON DELETE CASCADE,
st_comment text,
te_comment text,
te_comment_time datetime,
st_comment_time datetime
) DEFAULT CHARACTER SET utf8;

CREATE TABLE norm_quiz_tbl (
quiz_id bigint PRIMARY KEY AUTO_INCREMENT,
quiz_nam text,
groupid bigint REFERENCES groups (groupid) ON DELETE SET NULL,
comment text,
duration int,
ave_score  float8,
sd_score float8,
max_score int DEFAULT 0,
min_score int DEFAULT 0,
create_time datetime,
update_time datetime,
create_user bigint REFERENCES users (uid) ON DELETE SET NULL,
update_user bigint REFERENCES users (uid) ON DELETE SET NULL,
ans_cnt int DEFAULT 0
) DEFAULT CHARACTER SET utf8;

CREATE TABLE norm_quiz_prac_link (
quiz_prac_link_id  bigint PRIMARY KEY AUTO_INCREMENT,
quiz_id bigint REFERENCES norm_quiz_tbl (quiz_id) ON DELETE CASCADE,
practice_id bigint,
score int DEFAULT 0,
quiz_order int
) DEFAULT CHARACTER SET utf8;

CREATE TABLE norm_quiz_attempt_tbl (
attempt_id bigint PRIMARY KEY AUTO_INCREMENT,
uid bigint REFERENCES users (uid) ON DELETE SET NULL,
quiz_prac_link_id bigint REFERENCES norm_quiz_prac_link (quiz_prac_link_id) ON DELETE CASCADE,
is_right int,
event_link_id bigint NOT NULL REFERENCES norm_event_link_tbl(event_link_id) ON DELETE SET NULL,
ans_txt text,
CONSTRAINT norm_quiz_attempt_tbl_pk UNIQUE(event_link_id, uid,quiz_prac_link_id)
) DEFAULT CHARACTER SET utf8;

CREATE TABLE norm_quiz_result_tbl (
result_id bigint PRIMARY KEY AUTO_INCREMENT,
uid bigint REFERENCES users (uid) ON DELETE SET NULL,
quiz_id bigint NOT NULL REFERENCES norm_quiz_tbl (quiz_id) ON DELETE CASCADE,
create_time datetime,
event_link_id bigint NOT NULL REFERENCES norm_event_link_tbl(event_link_id) ON DELETE SET NULL,
score int,
CONSTRAINT norm_quiz_res_tbl_pk UNIQUE(event_link_id, uid)
) DEFAULT CHARACTER SET utf8;

CREATE TABLE norm_comment_dur_lec_tbl (
comment_id bigint PRIMARY KEY AUTO_INCREMENT,
uid bigint REFERENCES users (uid) ON DELETE SET NULL,
lecture_id bigint NOT NULL REFERENCES norm_lecture_tbl(lecture_id) ON DELETE CASCADE,
create_time datetime,
dur_comment text
) DEFAULT CHARACTER SET utf8;

CREATE TABLE norm_lec_pres_tbl (
uid bigint REFERENCES users (uid) ON DELETE SET NULL,
lecture_id bigint REFERENCES norm_lecture_tbl (lecture_id) ON DELETE SET NULL,
status int,
create_time datetime,
update_time datetime,
CONSTRAINT norm_lec_pres_uniq UNIQUE (uid,lecture_id)
) DEFAULT CHARACTER SET utf8;

CREATE TABLE norm_note_keyword_tbl (
note_keyword_id bigint PRIMARY KEY AUTO_INCREMENT,
event_id bigint,
event_type int,
score int
) DEFAULT CHARACTER SET utf8;

CREATE TABLE norm_note_key_text_tbl (
note_keyword_id bigint REFERENCES note_keyword_tbl (note_keyword_id) ON DELETE CASCADE,
key_word_text character varying(100) binary,
CONSTRAINT note_key_text_pk PRIMARY KEY(note_keyword_id, key_word_text)
) DEFAULT CHARACTER SET utf8;

CREATE TABLE norm_original_backup_note_tbl (
note_id bigint PRIMARY KEY REFERENCES norm_note_tbl (note_id) ON DELETE CASCADE,
student_id bigint REFERENCES users (uid) ON DELETE CASCADE,
event_link_id bigint NOT NULL REFERENCES norm_event_link_tbl(event_link_id) ON DELETE CASCADE,
note_text text,
create_time datetime,
update_time datetime
) DEFAULT CHARACTER SET utf8;

CREATE TABLE norm_note_show_others_tbl (
note_id bigint REFERENCES norm_note_tbl (note_id) ON DELETE CASCADE,
uid bigint REFERENCES users (uid) ON DELETE CASCADE,
CONSTRAINT norm_note_show_uniq UNIQUE(note_id,uid))
DEFAULT CHARACTER SET utf8;

CREATE TABLE norm_eval_note_tbl (
uid bigint REFERENCES users (uid) ON DELETE CASCADE,
note_id bigint REFERENCES norm_note_tbl (note_id) ON DELETE CASCADE,
eval smallint,
create_time datetime,
CONSTRAINT norm_note_eval_uniq UNIQUE(note_id,uid))
DEFAULT CHARACTER SET utf8;